#!/usr/bin/env node
"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.main = exports.getPortFromInput = void 0;
const meow = require("meow");
const _1 = require(".");
const cli = meow(`
Usage: 
  $ graphql-playground-mock FILE_PATH

GraphQL Playground Server mocks givin GraphQL Schema file(File must be GraphQL SDL syntax) at http://localhost:4000 (by default)

Options:
  --port, -p      Output in JSON format (based on introspection query)
`, {
    flags: {
        port: {
            type: 'number',
            alias: 'p',
        },
    },
});
const defaultPort = 4000;
const getPortFromInput = (cli) => {
    if (Number.isNaN(cli.flags.port) || typeof cli.flags.port === 'undefined') {
        return defaultPort;
    }
    else {
        return cli.flags.port;
    }
};
exports.getPortFromInput = getPortFromInput;
const main = (cli) => __awaiter(void 0, void 0, void 0, function* () {
    const [filepath] = cli.input;
    if (!filepath) {
        console.warn('No filepath provided');
        return;
    }
    const port = exports.getPortFromInput(cli);
    yield _1.server(filepath).listen(port).then(({ url }) => {
        console.log(`🚀 GraphQL Mock Server is ready at ${url}`);
    });
});
exports.main = main;
if (process.env.NODE_ENV !== 'test')
    exports.main(cli);
//# sourceMappingURL=bin.js.map