"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const graphql_import_1 = require("graphql-import");
const bin_1 = require("../bin");
const index = require("../");
jest.mock('graphql-import');
describe('getPortFromInput', () => {
    test('returns default port when givin port is undefined', () => {
        const noport = bin_1.getPortFromInput({
            flags: {
                port: undefined,
            },
        });
        expect(noport).toEqual(4000);
    });
    test('returns default port when givin port is NaN', () => {
        const noport = bin_1.getPortFromInput({
            flags: {
                port: NaN,
            },
        });
        expect(noport).toEqual(4000);
    });
    test('return givin port', () => {
        const noport = bin_1.getPortFromInput({
            flags: {
                port: 5000,
            },
        });
        expect(noport).toEqual(5000);
    });
});
describe('main', () => {
    beforeEach(() => {
        jest.restoreAllMocks();
    });
    test('warns on missing filepath', () => __awaiter(void 0, void 0, void 0, function* () {
        /**
         * Mocks
         */
        const consoleWarnMock = jest
            .spyOn(console, 'warn')
            .mockImplementation(() => false);
        const consoleLogMock = jest
            .spyOn(console, 'log')
            .mockImplementation(() => false);
        const serverMock = jest.spyOn(index, 'server');
        /**
         * Execution
         */
        yield bin_1.main({ input: [] });
        /**
         * Tests
         */
        expect(consoleWarnMock).toBeCalledWith('No filepath provided');
        expect(consoleWarnMock).toBeCalledTimes(1);
        expect(consoleLogMock).toBeCalledTimes(0);
        expect(serverMock).toBeCalledTimes(0);
    }));
    test('starts server with correct filepath', () => __awaiter(void 0, void 0, void 0, function* () {
        /**
         * Mocks
         */
        graphql_import_1.importSchema.mockReturnValueOnce(sampleGraphqlSchema);
        const consoleWarnMock = jest
            .spyOn(console, 'warn')
            .mockImplementation(() => false);
        const consoleLogMock = jest
            .spyOn(console, 'log')
            .mockImplementation(() => false);
        const server = index.server('filepath');
        const serverMock = jest.spyOn(index, 'server').mockImplementation(() => server);
        /**
         * Execution
         */
        yield bin_1.main({
            input: ["hoge"],
            flags: { port: undefined }
        });
        /**
         * Tests
         */
        expect(consoleWarnMock).toBeCalledTimes(0);
        expect(consoleLogMock).toBeCalledTimes(1);
        expect(serverMock).toBeCalledTimes(1);
        server.stop();
    }));
});
const sampleGraphqlSchema = `
type Book {
  title: String
}
type Query {
  books: [Book]
}
`;
//# sourceMappingURL=bin.test.js.map